pub struct LayerRelationship { /* private fields */ }Expand description
Relationship to another layer or table in the service.
ESRI Documentation
Source: https://developers.arcgis.com/rest/services-reference/enterprise/layer-feature-service/
Each layer or table can participate in one or more relationship classes.
The relationships array in a layer definition lists the relationships
that this layer participates in.
Example from ESRI
{
"id": 2,
"role": "esriRelRoleOrigin",
"keyField": "GlobalID",
"cardinality": "esriRelCardinalityOneToMany",
"relatedTableId": 3,
"name": "Buildings_Permits"
}Implementations
Sourceimpl LayerRelationship
Auto-generated by derive_getters::Getters.
impl LayerRelationship
Auto-generated by derive_getters::Getters.
Sourcepub fn role(&self) -> &RelationshipRole
pub fn role(&self) -> &RelationshipRole
Role of this layer in the relationship.
Sourcepub fn cardinality(&self) -> &RelationshipCardinality
pub fn cardinality(&self) -> &RelationshipCardinality
Cardinality of the relationship.
ID of the related layer or table.
Sourcepub fn composite_key_field_name(&self) -> &Option<String>
pub fn composite_key_field_name(&self) -> &Option<String>
Composite key field name (for composite key relationships).